@@ -4,18 +4,19 @@ use strict;
 use warnings;
 use Module::Load '';
 
-our $VERSION = '4.18.1';
+our $VERSION = '4.19.0';
 sub version { return $VERSION }
 sub sysname { 'bouncehammer'  }
 sub libname { 'Sisimai'       }
 
 sub make {
     # Wrapper method for parsing mailbox or Maildir/
-    # @param         [String] argv0      Path to mbox or Maildir/
-    # @param         [Hash]   argv1      Parser options
-    # @options argv1 [Integer] delivered 1 = Including "delivered" reason
-    # @return        [Array]             Parsed objects
-    # @return        [Undef]             Undef if the argument was wrong or an empty array
+    # @param         [String]  argv0      Path to mbox or Maildir/
+    # @param         [Hash]    argv1      Parser options
+    # @options argv1 [Integer] delivered  1 = Including "delivered" reason
+    # @options argv1 [Code]    hook       Code reference to a callback method
+    # @return        [Array]              Parsed objects
+    # @return        [Undef]              Undef if the argument was wrong or an empty array
     my $class = shift;
     my $argv0 = shift // return undef;
 
@@ -24,20 +25,20 @@ sub make {
 
     require Sisimai::Mail;
     my $mail = Sisimai::Mail->new($argv0);
-    my $mesg = undef;
-    my $data = undef;
     my $list = [];
-    my $opts = { 'delivered' => $argv1->{'delivered'} // 0 };
 
     return undef unless $mail;
     require Sisimai::Data;
     require Sisimai::Message;
 
+    my $methodargv = { 'delivered' => $argv1->{'delivered'} // 0 };
+    my $hookmethod = $argv1->{'hook'} || undef;
+
     while( my $r = $mail->read ) {
         # Read and parse each mail file
-        $mesg = Sisimai::Message->new('data' => $r);
+        my $mesg = Sisimai::Message->new('data' => $r, 'hook' => $hookmethod);
         next unless defined $mesg;
-        $data = Sisimai::Data->make('data' => $mesg, %$opts);
+        my $data = Sisimai::Data->make('data' => $mesg, %$methodargv);
         push @$list, @$data if scalar @$data;
     }
 
@@ -47,24 +48,25 @@ sub make {
 
 sub dump {
     # Wrapper method to parse mailbox/Maildir and dump as JSON
-    # @param         [String]  argv0     Path to mbox or Maildir/
-    # @param         [Hash]    argv1     Parser options
-    # @options argv1 [Integer] delivered 1 = Including "delivered" reason
-    # @return        [String]            Parsed data as JSON text
+    # @param         [String]  argv0      Path to mbox or Maildir/
+    # @param         [Hash]    argv1      Parser options
+    # @options argv1 [Integer] delivered  1 = Including "delivered" reason
+    # @options argv1 [Code]    hook       Code reference to a callback method
+    # @return        [String]             Parsed data as JSON text
     my $class = shift;
     my $argv0 = shift // return undef;
 
     die ' ***error: wrong number of arguments' if scalar @_ % 2;
     my $argv1 = { @_ };
-
-    my $parseddata = __PACKAGE__->make($argv0, %$argv1) // [];
-    my $jsonobject = undef;
+    my $nyaan = __PACKAGE__->make($argv0, %$argv1) // [];
 
     # Dump as JSON
     Module::Load::load('JSON', '-convert_blessed_universally');
-    $jsonobject = JSON->new->allow_blessed->convert_blessed;
+    my $jsonobject = JSON->new->allow_blessed->convert_blessed;
+    my $jsonstring = $jsonobject->encode($nyaan);
 
-    return $jsonobject->encode($parseddata);
+    utf8::encode $jsonstring if utf8::is_utf8 $jsonstring;
+    return $jsonstring;
 }
 
 sub engine {
@@ -116,6 +118,17 @@ sub reason {
     return $table;
 }
 
+sub match {
+    # Try to match with message patterns
+    # @param    [String]    Error message text
+    # @return   [String]    Reason text
+    my $class = shift;
+    my $argvs = shift || return undef;
+
+    require Sisimai::Reason;
+    return Sisimai::Reason->match($argvs);
+}
+
 1;
 __END__
 
@@ -185,6 +198,8 @@ C<dump> method provides feature to get parsed data from bounced email as JSON.
     my $v = Sisimai->dump('/path/to/mbox'); # or Path to Maildir
     print $v;                               # JSON string
 
+=head1 OTHER WAYS TO PARSE
+
 =head2 Read email data from STDIN
 
 If you want to pass email data from STDIN, specify B<STDIN> at the first argument
@@ -192,6 +207,27 @@ of dump() and make() method like following command:
 
     % cat ./path/to/bounce.eml | perl -MSisimai -lE 'print Sisimai->dump(STDIN)'
 
+=head2 Callback Feature
+
+Beggining from v4.19.0, `hook` argument is available to callback user defined
+method like the following codes:
+
+    my $callbackto = sub {
+        my $emdata = shift;
+        my $caught = { 'x-mailer' => '' };
+
+        if( $emdata->{'body'} =~ m/^X-Mailer:\s*(.+)$/m ) {
+            $caught->{'x-mailer'} = $1;
+        }
+        return $caught;
+    };
+    my $data = Sisimai->make('/path/to/mbox', 'hook' => $callbackto);
+    my $json = Sisimai->dump('/path/to/mbox', 'hook' => $callbackto);
+
+    print $data->[0]->catch->{'x-mailer'};    # Apple Mail (2.1283)
+
+=head1 OTHER METHODS
+
 =head2 C<B<engine()>>
 
 C<engine> method provides table including parser engine list and its description.
