@@ -16,8 +16,9 @@ my $rwaccessors = [
     'header',   # [Hash]   Header part of a email
     'ds',       # [Array]  Parsed data by Sisimai::MTA::*
     'rfc822',   # [Hash]   Header part of the original message
+    'catch'     # [?]      The results returned by hook method
 ];
-Class::Accessor::Lite->mk_accessors( @$rwaccessors );
+Class::Accessor::Lite->mk_accessors(@$rwaccessors);
 
 my $EndOfEmail = Sisimai::String->EOM;
 my $DefaultSet = Sisimai::Order->another;
@@ -42,6 +43,9 @@ sub new {
     # Constructor of Sisimai::Message
     # @param         [Hash] argvs       Email text data
     # @options argvs [String] data      Entire email message
+    # @options argvs [Array]  load      User defined MTA module list
+    # @options argvs [Array]  order     The order of MTA modules
+    # @options argvs [Code]   hook      Reference to callback method
     # @return        [Sisimai::Message] Structured email data or Undef if each
     #                                   value of the arguments are missing
     my $class = shift;
@@ -49,7 +53,7 @@ sub new {
     my $email = $argvs->{'data'} // '';
     return undef unless length $email;
 
-    my $methodargv = { 'data' => $email };
+    my $methodargv = { 'data' => $email, 'hook' => $argvs->{'hook'} // undef };
     my $messageobj = undef;
     my $parameters = undef;
 
@@ -69,6 +73,7 @@ sub new {
         'header' => $parameters->{'header'},
         'ds'     => $parameters->{'ds'},
         'rfc822' => $parameters->{'rfc822'},
+        'catch'  => $parameters->{'catch'} || undef,
     };
     return bless($messageobj, __PACKAGE__);
 }
@@ -77,12 +82,22 @@ sub make {
     # Make data structure from the email message(a body part and headers)
     # @param         [Hash] argvs   Email data
     # @options argvs [String] data  Entire email message
+    # @options argvs [Array]  load  User defined MTA module list
+    # @options argvs [Array]  order The order of MTA modules
+    # @options argvs [Code]   hook  Reference to callback method
     # @return        [Hash]         Resolved data structure
     my $class = shift;
     my $argvs = { @_ };
     my $email = $argvs->{'data'};
 
-    my $processing = { 'from' => '', 'header' => {}, 'rfc822' => '', 'ds' => [] };
+    my $hookmethod = $argvs->{'hook'} || undef;
+    my $processing = {
+        'from'   => '',     # From_ line
+        'header' => {},     # Email header
+        'rfc822' => '',     # Original message part
+        'ds'     => [],     # Parsed data, Delivery Status
+        'catch'  => undef,  # Data parsed by callback method
+    };
     my @mtamodules = ();
 
     for my $e ( 'load', 'order' ) {
@@ -114,14 +129,12 @@ sub make {
         push @$ToBeLoaded, $e;
     }
 
-    # 0. Split email data to headers and a body part.
+    # 1. Split email data to headers and a body part.
     my $aftersplit = __PACKAGE__->divideup(\$email);
     return undef unless keys %$aftersplit;
 
-    # 1. Initialize variables for setting the value of each email header.
-    $TryOnFirst = [];
-
     # 2. Convert email headers from text to hash reference
+    $TryOnFirst = [];
     $processing->{'from'}   = $aftersplit->{'from'};
     $processing->{'header'} = __PACKAGE__->headers(\$aftersplit->{'header'});
 
@@ -131,12 +144,17 @@ sub make {
     }
 
     # 4. Rewrite message body for detecting the bounce reason
-    my $methodargv = { 'mail' => $processing, 'body' => \$aftersplit->{'body'} };
+    my $methodargv = { 
+        'hook' => $hookmethod,
+        'mail' => $processing, 
+        'body' => \$aftersplit->{'body'},
+    };
     my $bouncedata = __PACKAGE__->parse(%$methodargv);
 
     return undef unless $bouncedata;
     return undef unless keys %$bouncedata;
-    $processing->{'ds'} = $bouncedata->{'ds'};
+    $processing->{'ds'}    = $bouncedata->{'ds'};
+    $processing->{'catch'} = $bouncedata->{'catch'};
 
     # 5. Rewrite headers of the original message in the body part
     my $rfc822part = $bouncedata->{'rfc822'} || $aftersplit->{'body'};
@@ -378,6 +396,8 @@ sub parse {
 
     my $mesgentity = $argvs->{'mail'} || return '';
     my $bodystring = $argvs->{'body'} || return '';
+    my $hookmethod = $argvs->{'hook'} || undef;
+    my $havecaught = undef;
     my $mailheader = $mesgentity->{'header'};
 
     # PRECHECK_EACH_HEADER:
@@ -409,7 +429,6 @@ sub parse {
             # Content-Type: text/html;...
             $bodystring = Sisimai::String->to_plain($bodystring, 1);
         }
-
     } else {
         # NOT text/plain
         if( $$bodystring =~ $ReEncoding->{'quoted-print'} ) {
@@ -428,6 +447,14 @@ sub parse {
         }
     }
 
+    # Call hook method
+    if( ref $hookmethod eq 'CODE' ) {
+        # Execute hook method
+        my $p = { 'headers' => $mailheader, 'message' => $$bodystring };
+        eval { $havecaught = $hookmethod->($p) };
+        warn sprintf(" ***warning: Something is wrong in hook method:%s", $@) if $@;
+    }
+
     # EXPAND_FORWARDED_MESSAGE:
     # Check whether or not the message is a bounce mail.
     # Pre-Process email body if it is a forwarded bounce message.
@@ -497,6 +524,8 @@ sub parse {
         last;
 
     } # End of while(SCANNER)
+
+    $scannedset->{'catch'} = $havecaught if $scannedset;
     return $scannedset;
 }
 
@@ -549,6 +578,22 @@ in the argument of this method as an array reference like following code:
                         'load' => ['Your::Custom::MTA::Module']
                   );
 
+Beggining from v4.19.0, `hook` argument is available to callback user defined
+method like the following codes:
+
+    my $cmethod = sub {
+        my $argv = shift;
+        my $data = { 'x-mailer' => '' };
+
+        if( $argv->{'message'} =~ m/^X-Mailer:\s*(.+)$/m ) {
+            $data->{'x-mailer'} = $1;
+        }
+
+        return $data;
+    };
+    my $message = Sisimai::Message->new('data' => $mailtxt, 'hook' => $cmethod);
+    print $message->catch->{'x-mailer'};    # Apple Mail (2.1283)
+
 =head1 INSTANCE METHODS
 
 =head2 C<B<(from)>>
@@ -580,6 +625,11 @@ message.
     print $message->rfc822->{'from'};   # cat@example.com
     print $message->rfc822->{'to'};     # neko@example.jp
 
+=head2 C<B<catch()>>
+
+C<catch()> returns any data generated by user-defined method passed at the `hook`
+argument of new() constructor.
+
 =head1 AUTHOR
 
 azumakuniyuki
